"""
Convenience import module for xwentity.
Allows:
  - `import xwentity`
  - `from xwentity import XWEntity`
This simply re-exports `exonware.xwmodels`.
"""

from exonware.xwmodels import *  # noqa: F401,F403
